﻿<#
    .SYNOPSIS
        Starts a process to handle commands, standard output, and standard error redirection.
    .DESCRIPTION
        Starts a process to handle commands, standard output, and standard error redirection.
    .PARAMETER FilePath
        Specifies the path to the executable.
    .PARAMETER ArgumentList
        Lists of arguments passed to the executable
    .PARAMETER TimeOut
        Specifies the timeout for the process. If the value is set to 0, the function waits for the process to end.   
#>
function Start-ProcessWithErrorHandling
{
    [CmdletBinding()]
    param ( 
        [parameter(Mandatory=$true)]
        [string]$FilePath,
        [parameter(Mandatory=$true)]
        [string[]]$ArgumentList,
        [parameter(Mandatory=$false)]
        [int]$TimeOut = 0
    )

    Write-Verbose "Running external command: $FilePath $ArgumentList"

    $StdErrFile = [System.IO.Path]::GetTempFileName()
    $StdOutFile = [System.IO.Path]::GetTempFileName()

    $result = Start-Process -FilePath $FilePath -PassThru -NoNewWindow -RedirectStandardError $StdErrFile -RedirectStandardOutput $StdOutFile -ArgumentList $ArgumentList

    # progress indication, assume upper bound 500 sec
    # start the pogress indicator after 5 sec
    [int]$percent = 0;
    $program = Split-Path $FilePath -Leaf
    while ($result.WaitForExit(5000) -eq $false) {
        Write-Progress -Activity "Running $program..." -PercentComplete $percent -CurrentOperation "$percent% complete" -Status "Please wait."

		# naive algoritm stops progress indication at 95%
        if ($percent -lt 95) {
            $percent = $percent + 1;
        }

		if ($TimeOut -ne 0) {
			# Decrease timeout with wait cycles
			$TimeOut -= 5
			if ($TimeOut -le 0) {
				Write-Error "Running $program timed out"
				$result | Stop-Process -ErrorAction SilentlyContinue
				break
			}
		}
    } 

    Write-Progress -Activity "Running $program..." -PercentComplete 100 -CurrentOperation "100% complete" -Completed -Status "Done."

    $outputFromProcess = Get-Content $StdOutFile 
    $errorOutputFromProcess = Get-Content $StdOutFile 

    # Many exe files send the same content to stderr and stdout
    # if we have the same number of lines in the stderr and stdout, we will only write log the stderr
	# if the line numbers are different we will write both logs
    if (@($outputFromProcess).Count -ne @($errorOutputFromProcess).Count) {
        $outputFromProcess | ForEach-Object {Write-Verbose "   $_"} # indent
    }

    $errorOutputFromProcess | ForEach-Object {Write-Verbose "   $_"} # indent

    [int]$exitCode = $result.ExitCode
    if ($exitCode -ne 0)
    {
        [string] $output = $errorOutputFromProcess
        Write-Error "$FilePath $ArgumentList failed with error $exitCode`n$output"
    }
}
Export-ModuleMember -Function Start-ProcessWithErrorHandling

# SIG # Begin signature block
# MIILrwYJKoZIhvcNAQcCoIILoDCCC5wCAQExCzAJBgUrDgMCGgUAMGkGCisGAQQB
# gjcCAQSgWzBZMDQGCisGAQQBgjcCAR4wJgIDAQAABBAfzDtgWUsITrck0sYpfvNR
# AgEAAgEAAgEAAgEAAgEAMCEwCQYFKw4DAhoFAAQU27tYi1ouUIOGaSYa+yl0oB31
# LRigggkRMIIEKDCCAxCgAwIBAgILBAAAAAABL07hNVwwDQYJKoZIhvcNAQEFBQAw
# VzELMAkGA1UEBhMCQkUxGTAXBgNVBAoTEEdsb2JhbFNpZ24gbnYtc2ExEDAOBgNV
# BAsTB1Jvb3QgQ0ExGzAZBgNVBAMTEkdsb2JhbFNpZ24gUm9vdCBDQTAeFw0xMTA0
# MTMxMDAwMDBaFw0xOTA0MTMxMDAwMDBaMFExCzAJBgNVBAYTAkJFMRkwFwYDVQQK
# ExBHbG9iYWxTaWduIG52LXNhMScwJQYDVQQDEx5HbG9iYWxTaWduIENvZGVTaWdu
# aW5nIENBIC0gRzIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCyTxTn
# EL7XJnKrNpfvU79ChF5Y0Yoo/ENGb34oRFALdV0A1zwKRJ4gaqT3RUo3YKNuPxL6
# bfq2RsNqo7gMJygCVyjRUPdhOVW4w+ElhlI8vwUd17Oa+JokMUnVoqni05GrPjxz
# 7/Yp8cg10DB7f06SpQaPh+LO9cFjZqwYaSrBXrta6G6V/zuAYp2Zx8cvZtX9YhqC
# VVrG+kB3jskwPBvw8jW4bFmc/enWyrRAHvcEytFnqXTjpQhU2YM1O46MIwx1tt6G
# Sp4aPgpQSTic0qiQv5j6yIwrJxF+KvvO3qmuOJMi+qbs+1xhdsNE1swMfi9tBoCi
# dEC7tx/0O9dzVB/zAgMBAAGjgfowgfcwDgYDVR0PAQH/BAQDAgEGMBIGA1UdEwEB
# /wQIMAYBAf8CAQAwHQYDVR0OBBYEFAhu2Lacir/tPtfDdF3MgB+oL1B6MEcGA1Ud
# IARAMD4wPAYEVR0gADA0MDIGCCsGAQUFBwIBFiZodHRwczovL3d3dy5nbG9iYWxz
# aWduLmNvbS9yZXBvc2l0b3J5LzAzBgNVHR8ELDAqMCigJqAkhiJodHRwOi8vY3Js
# Lmdsb2JhbHNpZ24ubmV0L3Jvb3QuY3JsMBMGA1UdJQQMMAoGCCsGAQUFBwMDMB8G
# A1UdIwQYMBaAFGB7ZhpFDZfKiVAvfQTNNKj//P1LMA0GCSqGSIb3DQEBBQUAA4IB
# AQAiXMXdPfQLcNjj9efFjgkBu7GWNlxaB63HqERJUSV6rg2kGTuSnM+5Qia7O2yX
# 58fOEW1okdqNbfFTTVQ4jGHzyIJ2ab6BMgsxw2zJniAKWC/wSP5+SAeq10NYlHNU
# BDGpeA07jLBwwT1+170vKsPi9Y8MkNxrpci+aF5dbfh40r5JlR4VeAiR+zTIvoSt
# vODG3Rjb88rwe8IUPBi4A7qVPiEeP2Bpen9qA56NSvnwKCwwhF7sJnJCsW3LZMMS
# jNaES2dBfLEDF3gJ462otpYtpH6AA0+I98FrWkYVzSwZi9hwnOUtSYhgcqikGVJw
# Q17a1kYDsGgOJO9K9gslJO8kMIIE4TCCA8mgAwIBAgISESGBEchVFJI+pYM5gzc8
# moWnMA0GCSqGSIb3DQEBBQUAMFExCzAJBgNVBAYTAkJFMRkwFwYDVQQKExBHbG9i
# YWxTaWduIG52LXNhMScwJQYDVQQDEx5HbG9iYWxTaWduIENvZGVTaWduaW5nIENB
# IC0gRzIwHhcNMTQwMjI2MTUyOTM3WhcNMTUwMjI3MTUyOTM3WjB3MQswCQYDVQQG
# EwJJUzESMBAGA1UECBMJUmV5a2phdmlrMRIwEAYDVQQHEwlSZXlramF2aWsxEDAO
# BgNVBAoTB0FkdmFuaWExHDAaBgNVBAsTE0R5bmFtaWNzIE5hdiBUaHJvdW4xEDAO
# BgNVBAMTB0FkdmFuaWEwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDT
# fStE3keO1451Z+7xOdF8us3flCiSj9fX+bEhLyfAObXAQdzo1fC/Nf/ny03jQ1XU
# bPJggV/n0MGgLD6+sYKurHEmdYepsMqXLDXL6EnD5wZq1jRX/c9ISLbCstFJL3ni
# hIWXKvJBiblO2hFdyrT0dv/EbtqHVwQWUAp6nfmeLCmz/+Ox6QfM+bwY+DjymRce
# rJDqj52+LX2b63NMXmNiFULlRLdvyYYKdHsiQ6A7oXhc6q+8eZtLLJqKEpJmwvjt
# GBqDUojPl8h3tBddb/kjLfkRfsSlC8Zo86mJ7MFnvoF3ofLPvPoF8fnViDlVEpHN
# izpYbdICSUlUb6WsQ5gJAgMBAAGjggGLMIIBhzAOBgNVHQ8BAf8EBAMCB4AwTAYD
# VR0gBEUwQzBBBgkrBgEEAaAyATIwNDAyBggrBgEFBQcCARYmaHR0cHM6Ly93d3cu
# Z2xvYmFsc2lnbi5jb20vcmVwb3NpdG9yeS8wCQYDVR0TBAIwADATBgNVHSUEDDAK
# BggrBgEFBQcDAzA+BgNVHR8ENzA1MDOgMaAvhi1odHRwOi8vY3JsLmdsb2JhbHNp
# Z24uY29tL2dzL2dzY29kZXNpZ25nMi5jcmwwgYYGCCsGAQUFBwEBBHoweDBABggr
# BgEFBQcwAoY0aHR0cDovL3NlY3VyZS5nbG9iYWxzaWduLmNvbS9jYWNlcnQvZ3Nj
# b2Rlc2lnbmcyLmNydDA0BggrBgEFBQcwAYYoaHR0cDovL29jc3AyLmdsb2JhbHNp
# Z24uY29tL2dzY29kZXNpZ25nMjAdBgNVHQ4EFgQUWhjFMoC/nYEsXezeEHlMU75h
# 1hIwHwYDVR0jBBgwFoAUCG7YtpyKv+0+18N0XcyAH6gvUHowDQYJKoZIhvcNAQEF
# BQADggEBAC2bIivs17GAdUYJHb4Uemglh2e/jq9C5tCKiBIfNUVGdUgrKqoXGB3x
# DpTZacMK9HepqjYoYVprlpAhDhbuVtIrgIOMvR1IjcSyVfC8X4dbFtfGV+4twIgV
# gVaPZrhsAcdF7ur7+DbNXRKPLunwMSeGP+jORyVLMjwgXjFktQR9pNeLXNfWirCp
# 6LX3AID7cFSpQ4PBD7BTiwQpWwcE0MX/9+S4HzCHZt7lOnF9P0J4B/NEyLTgqlzU
# f4P9pelL4iSUNkulu1H7E/sehx1nuRMLWSiqMnLnLWzKYVm3C+vykWNutJpFuFOb
# evcUoXLCGtEPU2U9AIRNNMgGPYAfmPoxggIIMIICBAIBATBnMFExCzAJBgNVBAYT
# AkJFMRkwFwYDVQQKExBHbG9iYWxTaWduIG52LXNhMScwJQYDVQQDEx5HbG9iYWxT
# aWduIENvZGVTaWduaW5nIENBIC0gRzICEhEhgRHIVRSSPqWDOYM3PJqFpzAJBgUr
# DgMCGgUAoHgwGAYKKwYBBAGCNwIBDDEKMAigAoAAoQKAADAZBgkqhkiG9w0BCQMx
# DAYKKwYBBAGCNwIBBDAcBgorBgEEAYI3AgELMQ4wDAYKKwYBBAGCNwIBFTAjBgkq
# hkiG9w0BCQQxFgQU9fsl6gydG+Vc+DnhLZ8d0/BMWSgwDQYJKoZIhvcNAQEBBQAE
# ggEAmopoeNHWhKlk7xqXLijmo0rg6bX7DnX5cmBNIsQZGXNqUjvoJGDBb64cRn5o
# 7YvE5jYWSQyrSHYy5Ww7aE/JoTXKgq4VjQao4tggqN21dAcFzLwSWP3AqTqokbGy
# uyJATAzKIsoGIviW569V9SGPGhptkI4upDJjb6J06UXufG8Zz/8BxEZErmFYOBve
# k7qeL/YUnqxQm1l8iNfFmFYd3pgXyynk+0Uz+jur6wU3+UiN32rVFSOoI7lu9CU2
# lbx/cvMhhVS0XzB+Rtk6+q6zjB0CfngVsu7fCfzU6oOzoXg90bllSFlzp4afdHRR
# mWcztSNUCmm7m5a8ovrZza2PuQ==
# SIG # End signature block
