﻿# Info about code signing certificates:
#
#   You will need a PFX file if you want to sign the ClickOnce deployment.
#
#   You can either create a self-signed certificate FOR TESTING ONLY, or you can obtain a certificate from 
#   a trusted root authority.
#
#   See http://msdn.microsoft.com/en-us/library/hh997056(v=nav.70).aspx for more details on how to sign a ClickOnce deployment.
#
#   In order to create a self-signed certificate, perform the following steps.
#     (see http://msdn.microsoft.com/en-US/library/bfsktky3(v=vs.110).aspx and http://msdn.microsoft.com/en-us/library/windows/hardware/ff550672(v=vs.85).aspx
#     for details)
#
#   Create a test certificate:
#       makecert.exe -r -n "CN=This is the clickonce publisher" -sv ClickOnceSignaturePrivateKey.pvk ClickOnceSignatureCertificate.cer
#   where
#       -r = create a self-signed certificate (only use for testing)
#       -n = the common name
#       -sv = private key file to be created
#       .cer file = the certificate file to be created
#   You will be prompted to enter the private key password 3 times (2 times to create the .pvk file, 1 time to use the .pvk file to create the .cer).
#   Enter for example 'clickonceprivatekeypassword'.
#   The result will be two new files:
#       ClickOnceSignaturePrivateKey.pvk which contains the private key part of the certificate
#       ClickOnceSignatureCertificate.cer which contains the public key part of the certificate
#
#   Then you need to convert the two .cer and .pvk files into one .pfx file:
#       pvk2pfx.exe -pvk ClickOnceSignaturePrivateKey.pvk -spc ClickOnceSignatureCertificate.cer -pfx ClickOnceSignature.pfx -po "clickoncesignaturepassword"
#   or
#       pvk2pfx.exe -pvk ClickOnceSignaturePrivateKey.pvk -spc ClickOnceSignatureCertificate.cer -pfx ClickOnceSignature.pfx
#   where
#       -pvk = the private key file
#       -spc = the certificate file
#       -po = the optional password to protect the pfx file with (not the same as the private key password)
#       -pfx = the combined certificate file to be created
#   You will be prompted to enter the private key password again.
#   The result will be one new file:
#       ClickOnceSignature.pfx which contains both the public and private part of the certificate. This file can be used for
#       signing the ClickOnce deployment.
#
#   Note if it's a test certificate: You will also need to import it on the client machines where you want to run the ClickOnce deployment.
#       Import it like this:
#           certutil -p "clickoncesignaturepassword" -importpfx ClickOnceSignature.pfx
#       If you don't import on the client machine, the certificate will be shown as not trusted, but you will still be able to install.
#
function Set-ManifestSignatureRemotely
{
    [CmdletBinding()]
    param (
        [parameter(Mandatory=$true,ValueFromPipeline=$true)]
        [string] $ManifestFile,

        [parameter(Mandatory=$true,ValueFromPipeline=$true)]
        [string] $CodeSigningPfxFile,

        [parameter(Mandatory=$true,ValueFromPipeline=$true)]
        [System.Security.SecureString] $CodeSigningPfxPassword = $null,

        [parameter(Mandatory=$true)]
        [string] $MageExeLocation,

        [parameter(Mandatory=$true)]
        [System.Management.Automation.Runspaces.PSSession] $Session
    )
    PROCESS {
 
        # NOTE: We need to sign the manifest locally. For some reason, it fails with "Unable to open certificate... Access denied." when 
        # trying to sign with mage through a PS session. The strange thing is that if you remote desktop to the remote machine and run "mage -sign"
        # manually (potentially on some unrelated manifest/certificate), THEN from then on you can also sign through a PS session.
        #
        # To work around this issue, we do the signing in three steps: copy from the remote machine, sign, copy back to the remote machine. 

        Write-Verbose "Signing $ManifestFile with certificate from pfx file $CodeSigningPfxFile..."

        # Copy locally
        $localFile = [System.IO.Path]::GetTempFileName()
        Copy-FileFromRemoteMachine -RemoteSourceFile $ManifestFile -LocalDestinationFile $localFile -Session $Session

        # Run mage.exe
        if ($CodeSigningPfxPassword)
        {
            $clearTextPassword = [System.Runtime.InteropServices.Marshal]::PtrToStringAuto([System.Runtime.InteropServices.Marshal]::SecureStringToBSTR($CodeSigningPfxPassword))
            Start-ProcessWithErrorHandling -FilePath $MageExeLocation -ArgumentList "-Sign `"$localFile`" -CertFile `"$CodeSigningPfxFile`" -password $clearTextPassword"
        }
        else
        {
            Start-ProcessWithErrorHandling -FilePath $MageExeLocation -ArgumentList "-Sign `"$localFile`" -CertFile `"$CodeSigningPfxFile`""
        }

        # Copy the signed file back
        Copy-FileToRemoteMachine -SourceFile $localFile -DestinationFile $ManifestFile -Session $Session
        Remove-Item $localFile

        Write-Verbose "Done signing $ManifestFile with certificate from pfx file $CodeSigningPfxFile."
    }
}

# SIG # Begin signature block
# MIILrwYJKoZIhvcNAQcCoIILoDCCC5wCAQExCzAJBgUrDgMCGgUAMGkGCisGAQQB
# gjcCAQSgWzBZMDQGCisGAQQBgjcCAR4wJgIDAQAABBAfzDtgWUsITrck0sYpfvNR
# AgEAAgEAAgEAAgEAAgEAMCEwCQYFKw4DAhoFAAQUlJiJCzCPmFYZIY6M/Ti/rYMZ
# iC6gggkRMIIEKDCCAxCgAwIBAgILBAAAAAABL07hNVwwDQYJKoZIhvcNAQEFBQAw
# VzELMAkGA1UEBhMCQkUxGTAXBgNVBAoTEEdsb2JhbFNpZ24gbnYtc2ExEDAOBgNV
# BAsTB1Jvb3QgQ0ExGzAZBgNVBAMTEkdsb2JhbFNpZ24gUm9vdCBDQTAeFw0xMTA0
# MTMxMDAwMDBaFw0xOTA0MTMxMDAwMDBaMFExCzAJBgNVBAYTAkJFMRkwFwYDVQQK
# ExBHbG9iYWxTaWduIG52LXNhMScwJQYDVQQDEx5HbG9iYWxTaWduIENvZGVTaWdu
# aW5nIENBIC0gRzIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCyTxTn
# EL7XJnKrNpfvU79ChF5Y0Yoo/ENGb34oRFALdV0A1zwKRJ4gaqT3RUo3YKNuPxL6
# bfq2RsNqo7gMJygCVyjRUPdhOVW4w+ElhlI8vwUd17Oa+JokMUnVoqni05GrPjxz
# 7/Yp8cg10DB7f06SpQaPh+LO9cFjZqwYaSrBXrta6G6V/zuAYp2Zx8cvZtX9YhqC
# VVrG+kB3jskwPBvw8jW4bFmc/enWyrRAHvcEytFnqXTjpQhU2YM1O46MIwx1tt6G
# Sp4aPgpQSTic0qiQv5j6yIwrJxF+KvvO3qmuOJMi+qbs+1xhdsNE1swMfi9tBoCi
# dEC7tx/0O9dzVB/zAgMBAAGjgfowgfcwDgYDVR0PAQH/BAQDAgEGMBIGA1UdEwEB
# /wQIMAYBAf8CAQAwHQYDVR0OBBYEFAhu2Lacir/tPtfDdF3MgB+oL1B6MEcGA1Ud
# IARAMD4wPAYEVR0gADA0MDIGCCsGAQUFBwIBFiZodHRwczovL3d3dy5nbG9iYWxz
# aWduLmNvbS9yZXBvc2l0b3J5LzAzBgNVHR8ELDAqMCigJqAkhiJodHRwOi8vY3Js
# Lmdsb2JhbHNpZ24ubmV0L3Jvb3QuY3JsMBMGA1UdJQQMMAoGCCsGAQUFBwMDMB8G
# A1UdIwQYMBaAFGB7ZhpFDZfKiVAvfQTNNKj//P1LMA0GCSqGSIb3DQEBBQUAA4IB
# AQAiXMXdPfQLcNjj9efFjgkBu7GWNlxaB63HqERJUSV6rg2kGTuSnM+5Qia7O2yX
# 58fOEW1okdqNbfFTTVQ4jGHzyIJ2ab6BMgsxw2zJniAKWC/wSP5+SAeq10NYlHNU
# BDGpeA07jLBwwT1+170vKsPi9Y8MkNxrpci+aF5dbfh40r5JlR4VeAiR+zTIvoSt
# vODG3Rjb88rwe8IUPBi4A7qVPiEeP2Bpen9qA56NSvnwKCwwhF7sJnJCsW3LZMMS
# jNaES2dBfLEDF3gJ462otpYtpH6AA0+I98FrWkYVzSwZi9hwnOUtSYhgcqikGVJw
# Q17a1kYDsGgOJO9K9gslJO8kMIIE4TCCA8mgAwIBAgISESGBEchVFJI+pYM5gzc8
# moWnMA0GCSqGSIb3DQEBBQUAMFExCzAJBgNVBAYTAkJFMRkwFwYDVQQKExBHbG9i
# YWxTaWduIG52LXNhMScwJQYDVQQDEx5HbG9iYWxTaWduIENvZGVTaWduaW5nIENB
# IC0gRzIwHhcNMTQwMjI2MTUyOTM3WhcNMTUwMjI3MTUyOTM3WjB3MQswCQYDVQQG
# EwJJUzESMBAGA1UECBMJUmV5a2phdmlrMRIwEAYDVQQHEwlSZXlramF2aWsxEDAO
# BgNVBAoTB0FkdmFuaWExHDAaBgNVBAsTE0R5bmFtaWNzIE5hdiBUaHJvdW4xEDAO
# BgNVBAMTB0FkdmFuaWEwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDT
# fStE3keO1451Z+7xOdF8us3flCiSj9fX+bEhLyfAObXAQdzo1fC/Nf/ny03jQ1XU
# bPJggV/n0MGgLD6+sYKurHEmdYepsMqXLDXL6EnD5wZq1jRX/c9ISLbCstFJL3ni
# hIWXKvJBiblO2hFdyrT0dv/EbtqHVwQWUAp6nfmeLCmz/+Ox6QfM+bwY+DjymRce
# rJDqj52+LX2b63NMXmNiFULlRLdvyYYKdHsiQ6A7oXhc6q+8eZtLLJqKEpJmwvjt
# GBqDUojPl8h3tBddb/kjLfkRfsSlC8Zo86mJ7MFnvoF3ofLPvPoF8fnViDlVEpHN
# izpYbdICSUlUb6WsQ5gJAgMBAAGjggGLMIIBhzAOBgNVHQ8BAf8EBAMCB4AwTAYD
# VR0gBEUwQzBBBgkrBgEEAaAyATIwNDAyBggrBgEFBQcCARYmaHR0cHM6Ly93d3cu
# Z2xvYmFsc2lnbi5jb20vcmVwb3NpdG9yeS8wCQYDVR0TBAIwADATBgNVHSUEDDAK
# BggrBgEFBQcDAzA+BgNVHR8ENzA1MDOgMaAvhi1odHRwOi8vY3JsLmdsb2JhbHNp
# Z24uY29tL2dzL2dzY29kZXNpZ25nMi5jcmwwgYYGCCsGAQUFBwEBBHoweDBABggr
# BgEFBQcwAoY0aHR0cDovL3NlY3VyZS5nbG9iYWxzaWduLmNvbS9jYWNlcnQvZ3Nj
# b2Rlc2lnbmcyLmNydDA0BggrBgEFBQcwAYYoaHR0cDovL29jc3AyLmdsb2JhbHNp
# Z24uY29tL2dzY29kZXNpZ25nMjAdBgNVHQ4EFgQUWhjFMoC/nYEsXezeEHlMU75h
# 1hIwHwYDVR0jBBgwFoAUCG7YtpyKv+0+18N0XcyAH6gvUHowDQYJKoZIhvcNAQEF
# BQADggEBAC2bIivs17GAdUYJHb4Uemglh2e/jq9C5tCKiBIfNUVGdUgrKqoXGB3x
# DpTZacMK9HepqjYoYVprlpAhDhbuVtIrgIOMvR1IjcSyVfC8X4dbFtfGV+4twIgV
# gVaPZrhsAcdF7ur7+DbNXRKPLunwMSeGP+jORyVLMjwgXjFktQR9pNeLXNfWirCp
# 6LX3AID7cFSpQ4PBD7BTiwQpWwcE0MX/9+S4HzCHZt7lOnF9P0J4B/NEyLTgqlzU
# f4P9pelL4iSUNkulu1H7E/sehx1nuRMLWSiqMnLnLWzKYVm3C+vykWNutJpFuFOb
# evcUoXLCGtEPU2U9AIRNNMgGPYAfmPoxggIIMIICBAIBATBnMFExCzAJBgNVBAYT
# AkJFMRkwFwYDVQQKExBHbG9iYWxTaWduIG52LXNhMScwJQYDVQQDEx5HbG9iYWxT
# aWduIENvZGVTaWduaW5nIENBIC0gRzICEhEhgRHIVRSSPqWDOYM3PJqFpzAJBgUr
# DgMCGgUAoHgwGAYKKwYBBAGCNwIBDDEKMAigAoAAoQKAADAZBgkqhkiG9w0BCQMx
# DAYKKwYBBAGCNwIBBDAcBgorBgEEAYI3AgELMQ4wDAYKKwYBBAGCNwIBFTAjBgkq
# hkiG9w0BCQQxFgQUO+zyXY0q88FwB59pHT2+CX7FaVYwDQYJKoZIhvcNAQEBBQAE
# ggEAXcQPquTeJquwK3jm0qvCu4qhvemPPpmEL+fnf3IS0lgm1d8Zv7cGzL9eAJIq
# srPXFNypQVgZyZkH3PTUwKjndJj8OLJ5p3vmDtLeCCggOREo7S5FvUBy+D5dxzY2
# fOyci3N/T/UYVlna2mVRt8C0HcyOtvSeL+ZLwi6A9ToiguzIuST2ybNtPVccsWWy
# nWTNNdoP6l7fhyN9DAJUcteAQ37gvHqo+hh1vL2/ykPMDKAL1xcSK+osJQgRbPJk
# izRgeded1jmzk3MxYf5QEXqNgSHU885ElPG90xgqLWMng2TYQDH0kqRj7rYCLC9z
# ZK9S1oYLtVM3b3AfSKPP9OMfbQ==
# SIG # End signature block
